==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/es.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Compartido con usted",
    "Shared with others" : "Compartido con otros",
    "Shared by link" : "Compartido por medio de enlaces",
    "Nothing shared with you yet" : "Todavía no han compartido nada contigo",
    "Files and folders others share with you will show up here" : "Aquí aparecerán archivos y carpetas que otros compartan contigo",
    "Nothing shared yet" : "Aún no hay nada compartido",
    "Files and folders you share will show up here" : "Aquí aparecerán archivos y carpetas que usted comparta con otros",
    "No shared links" : "No hay enlaces compartidos",
    "Files and folders you share by link will show up here" : "Aquí aparecerán archivos y carpetas que usted comparta mediante un enlace",
    "You can upload into this folder" : "Usted puede cargar en esta carpeta",
    "No compatible server found at {remote}" : "No se ha encontrado un servidor compatible en {remote}",
    "Invalid server URL" : "URL del servidor inválida",
    "Failed to add the public link to your Nextcloud" : "No se ha podido añadir el enlace público a tu Nextcloud",
    "Share" : "Compartir",
    "No expiration date set" : "No se ha establecido fecha de caducidad",
    "Shared by" : "Compartido por",
    "Sharing" : "Compartiendo",
    "File shares" : "Archivos compartidos",
    "Downloaded via public link" : "Descargado vía enlace público",
    "Downloaded by %1$s" : "Descargado por %1$s",
    "Downloaded by {email}" : "Descargado por {email}",
    "%1$s downloaded via public link" : "%1$s descargado por vía enlace público",
    "{file} downloaded via public link" : "{file} descargado vía enlace público",
    "%1$s downloaded %2$s" : "%1$s descargó %2$s",
    "{email} downloaded {file}" : "{email} descargó {file}",
    "Shared with group %1$s" : "Compartido con el grupo %1$s",
    "Shared with group {group}" : "Compartido con el grupo {grupo}",
    "Removed share for group %1$s" : "Eliminado el compartido para el grupo %1$s",
    "Removed share for group {group}" : "Eliminado el compartido para el grupo {group}",
    "%2$s shared with group %1$s" : "%2$s compartido con el grupo %1$s",
    "{actor} shared with group {group}" : "{actor} compartió con el grupo {group}",
    "%2$s removed share for group %1$s" : "%2$s removió archivo del grupo %1$s",
    "{actor} removed share for group {group}" : "{actor} eliminó el compartido para el grupo {group}",
    "You shared %1$s with group %2$s" : "Usted ha compartido %1$s con el grupo %2$s",
    "You shared {file} with group {group}" : "Ha compartido {file} con el grupo {group}",
    "You removed group %2$s from %1$s" : "Ha eliminado el grupo %2$s de %1$s",
    "You removed group {group} from {file}" : "Ha eliminado el grupo  {group} del {file}",
    "%3$s shared %1$s with group %2$s" : "%3$s compartió %1$s con el grupo %2$s",
    "{actor} shared {file} with group {group}" : "{actor} compartió {file} con el grupo {group}",
    "%3$s removed group %2$s from %1$s" : "%3$s eliminó el grupo %2$s de %1$s",
    "{actor} removed group {group} from {file}" : "{actor} eliminó grupo {group} de {file}",
    "Shared as public link" : "Compartido como enlace público",
    "Removed public link" : "Eliminado enlace público",
    "%1$s shared as public link" : "%1$s compartido como enlace público",
    "{actor} shared as public link" : "{actor} compartió como enlace público",
    "%1$s removed public link" : "%1$s eliminó el enlace público",
    "{actor} removed public link" : "{actor} eliminó el enlace público",
    "You shared %1$s as public link" : "Compartió %1$s como un enlace público",
    "You shared {file} as public link" : "Compartió {file} como un enlace público",
    "You removed public link for %1$s" : "Eliminó el enlace público para %1$s",
    "You removed public link for {file}" : "Eliminó el enlace público para {file}",
    "%2$s shared %1$s as public link" : "%2$s compartió %1$s como un enlace público",
    "{actor} shared {file} as public link" : "{actor} compartió {file} como enlace público",
    "%2$s removed public link for %1$s" : "%2$s eliminó el enlace público para %1$s",
    "{actor} removed public link for {file}" : "{actor} eliminó el enlace público para {file}",
    "%1$s accepted the remote share" : "%1$s aceptó el recurso compartido remotamente",
    "{user} accepted the remote share" : "{user} aceptó el recurso compartido remotamente",
    "%1$s declined the remote share" : "%1$s rechazó el recurso compartido",
    "{user} declined the remote share" : "{user} rechazó el recurso compartido",
    "You received a new remote share %1$s from %2$s" : "Ha recibido un nuevo recurso compartido remoto %1$s de %2$s",
    "You received a new remote share {file} from {user}" : "Ha recibido un nuevo recurso compartido remoto {file} de {user}",
    "%2$s accepted the remote share of %1$s" : "%2$s aceptó el recurso compartido de %1$s",
    "{user} accepted the remote share of {file}" : "{user} aceptó la compartición remota de {file}",
    "%2$s declined the remote share of %1$s" : "%2$s rechazó el recurso compartido de %1$s",
    "{user} declined the remote share of {file}" : "{user} rechazó el recurso compartido de {file}",
    "%2$s unshared %1$s from you" : "%2$s dejó de compartir %1$s contigo",
    "{user} unshared {file} from you" : "{user} dejó de compartir {file} contigo",
    "Shared with %1$s" : "Compartido con %1$s",
    "Shared with {user}" : "Compartido con {user}",
    "Removed share for %1$s" : "Eliminó el recurso compartido a %1$s",
    "Removed share for {user}" : "Eliminó el recurso compartido a {user}",
    "%2$s shared with %1$s" : "%2$s compartió con %1$s",
    "{actor} shared with {user}" : "{actor} compartió con {user}",
    "%2$s removed share for %1$s" : "%2$s eliminó recurso compartido para %1$s",
    "{actor} removed share for {user}" : "{actor} eliminó recurso compartido para {user}",
    "Shared by %1$s" : "Compartido por %1$s",
    "Shared by {actor}" : "Compartido por {actor}",
    "%1$s removed share" : "%1$s eliminó el recurso compartido",
    "{actor} removed share" : "{actor} eliminó el recurso compartido",
    "You shared %1$s with %2$s" : "Usted compartió %1$s con %2$s",
    "You shared {file} with {user}" : "Ha compartido {file} con {user}",
    "You removed %2$s from %1$s" : "Ha eliminado %2$s de %1$s",
    "You removed {user} from {file}" : "Ha eliminado {user} de {file}",
    "%3$s shared %1$s with %2$s" : "%3$s compartió %1$s con %2$s",
    "{actor} removed {user} from {file}" : "{actor} eliminó a {user} de {file}",
    "%3$s removed %2$s from %1$s" : "%3$s eliminó a %2$s de %1$s",
    "%2$s shared %1$s with you" : "%2$s ha compartido %1$s con usted",
    "{actor} shared {file} with you" : "{actor} compartió {file} contigo",
    "%2$s removed you from %1$s" : "%2$s lo ha eliminado de %1$s",
    "{actor} removed you from {file}" : "{actor} lo ha eliminado de {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Un archivo o carpeta compartida por correo o enlace público fue  <strong>descargado</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Se ha compartido un archivo o carpeta desde <strong>otro servidor</strong>",
    "A file or folder has been <strong>shared</strong>" : "Se ha <strong>compartido</strong> un archivo o carpeta",
    "Wrong share ID, share doesn't exist" : "El ID del recurso compartido no es correcto, el recurso compartido no existe",
    "could not delete share" : "No se ha podido eliminar el recurso compartido",
    "Could not delete share" : "No se ha podido eliminar el recurso compartido",
    "Please specify a file or folder path" : "Por favor, especifica la ubicación de un archivo o carpeta",
    "Wrong path, file/folder doesn't exist" : "Ubicación incorrecta, el archivo/carpeta no existe",
    "Could not create share" : "No se ha podido compartir",
    "invalid permissions" : "Permisos incorrectos",
    "Please specify a valid user" : "Por favor, especifica un usuario válido",
    "Group sharing is disabled by the administrator" : "Compartir en grupo está deshabilitado por el administrador",
    "Please specify a valid group" : "Por favor, especifica un grupo válido",
    "Public link sharing is disabled by the administrator" : "Compartir enlaces de forma pública está deshabilitado por el administrador",
    "Public upload disabled by the administrator" : "La subida pública está deshabilitado por el administrador",
    "Public upload is only possible for publicly shared folders" : "La subida publica solo es posible poara las carpetas publicas compartidas",
    "Invalid date, date format must be YYYY-MM-DD" : "Fecha inválida, el formato de las fechas debe ser YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Compartir %s ha fallado porque el repositorio no admite compartidos del tipo %s",
    "Unknown share type" : "Tipo desconocido de recurso compartido",
    "Not a directory" : "No es un directorio",
    "Could not lock path" : "No se ha podido bloquear la ruta",
    "Wrong or no update parameter given" : "No se ha suministrado un parametro correcto",
    "Can't change permissions for public share links" : "No se pueden cambiar los permisos para los enlaces de recursos compartidos públicos",
    "Cannot increase permissions" : "No es posible aumentar permisos",
    "%s is publicly shared" : "%s ha sido compartido",
    "Share API is disabled" : "El API de compartir está deshabilitado",
    "This share is password-protected" : "Este elemento compartido está protegido por contraseña",
    "The password is wrong. Try again." : "La contraseña introducida es errónea. Inténtelo de nuevo.",
    "Password" : "Contraseña",
    "No entries found in this folder" : "No hay entradas en esta carpeta",
    "Name" : "Nombre",
    "Share time" : "Compartido hace",
    "Expiration date" : "Fecha de caducidad",
    "Sorry, this link doesn’t seem to work anymore." : "Vaya, este enlace parece que no volverá a funcionar.",
    "Reasons might be:" : "Las causas podrían ser:",
    "the item was removed" : "el elemento fue eliminado",
    "the link expired" : "el enlace expiró",
    "sharing is disabled" : "compartir está desactivado",
    "For more info, please ask the person who sent this link." : "Para mayor información, contacte a la persona que le envió el enlace.",
    "Add to your Nextcloud" : "Añadir a tu Nextcloud",
    "Download" : "Descargar",
    "Download %s" : "Descargar %s",
    "Direct link" : "Enlace directo",
    "Upload files to %s" : "Subir archivos a %s",
    "Select or drop files" : "Seleccione o arrastre y suelte archivos",
    "Uploading files…" : "Subiendo archivos...",
    "Uploaded files:" : "Archivos subidos:",
    "A public shared file or folder was <strong>downloaded</strong>" : "Se ha <strong>descargado</strong> un archivo o carpeta compartido públicamente",
    "You received a new remote share %2$s from %1$s" : "Recibió un nuevo recurso compartido remoto %2$s de %1$s",
    "You received a new remote share from %s" : "Ha recibido un nuevo recurso compartido remoto de %s",
    "%1$s accepted remote share %2$s" : "%1$s aceptó el recurso compartido remoto %2$s",
    "%1$s declined remote share %2$s" : "%1$s ha rechazado el recurso compartido remoto %2$s",
    "%1$s unshared %2$s from you" : "%1$s dejó de compartirse %2$s por ti",
    "Public shared folder %1$s was downloaded" : "Se descargó la carpeta pública compartida %1$s",
    "Public shared file %1$s was downloaded" : "Se descargó el archivo público compartido %1$s",
    "%2$s shared %1$s with %3$s" : "%2$s compartó %1$s con %3$s",
    "You removed the share of %2$s for %1$s" : "Ha cambiado el compartido %2$s por %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s eliminó la compartición de %3$s con %1$s",
    "%2$s shared %1$s with group %3$s" : "%2$s compartió %1$s con el grupo %3$s",
    "You removed the share of group %2$s for %1$s" : "Ha cambiado el compartido del grupo %2$s por %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s ha cambiado el compartido del grupo %3$s por %1$s",
    "%2$s shared %1$s via link" : "%2$s compartió %1$s vía enlace",
    "You shared %1$s via link" : "Ha compartido %1$s vía enlace",
    "You removed the public link for %1$s" : "Ha borrado el enlace público de %1$s",
    "%2$s removed the public link for %1$s" : "%2$s ha eliminado el enlace público de %1$s",
    "Your public link for %1$s expired" : "Su enlace público %1$s ha expirado",
    "The public link of %2$s for %1$s expired" : "El enlace público de %2$s para %1$s ha expirado",
    "%2$s removed the share for %1$s" : "%2$s ha borrado el compartido %1$s",
    "Shared with %2$s" : "Compartido con %2$s",
    "Shared with %3$s by %2$s" : "Compartido con %3$s por %2$s",
    "Removed share for %2$s" : "Borrado el compartido %2$s",
    "%2$s removed share for %3$s" : "%2$s ha borrado el compartido %3$s",
    "Shared with group %2$s" : "Compartido con el grupo %2$s",
    "Shared with group %3$s by %2$s" : "Compartido con el grupo %3$s por %2$s",
    "Removed share of group %2$s" : "Borrado el compartido del grupo %2$s",
    "%2$s removed share of group %3$s" : "%2$s ha borrado el compartido del grupo %3$s",
    "Shared via link by %2$s" : "Compartido vía enlace por %2$s",
    "Shared via public link" : "Compartido vía enlace público",
    "%2$s removed public link" : "%2$s ha borrado el enlace público",
    "Public link expired" : "El enlace público ha expirado",
    "Public link of %2$s expired" : "El enlace público %2$s ha expirado",
    "Shared by %2$s" : "Compartido por %2$s",
    "Shares" : "Compartidos"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/es.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Compartido contigo",
    "Shared with others" : "Compartido con otros",
    "Shared by link" : "Compartido por medio de enlaces",
    "Nothing shared with you yet" : "Todavía no han compartido nada contigo",
    "Files and folders others share with you will show up here" : "Aquí aparecerán archivos y carpetas que otros compartan contigo",
    "Nothing shared yet" : "Aún no hay nada compartido",
    "Files and folders you share will show up here" : "Aquí aparecerán archivos y carpetas que usted comparta con otros",
    "No shared links" : "No hay enlaces compartidos",
    "Files and folders you share by link will show up here" : "Aquí aparecerán archivos y carpetas que usted comparta mediante un enlace",
    "You can upload into this folder" : "Usted puede cargar en esta carpeta",
    "No compatible server found at {remote}" : "No se ha encontrado un servidor compatible en {remote}",
    "Invalid server URL" : "URL del servidor inválida",
    "Failed to add the public link to your Nextcloud" : "No se ha podido añadir el enlace público a tu Nextcloud",
    "Share" : "Compartir",
    "No expiration date set" : "No se ha establecido fecha de caducidad",
    "Shared by" : "Compartido por",
    "Sharing" : "Compartiendo",
    "File shares" : "Archivos compartidos",
    "Downloaded via public link" : "Descargado vía enlace público",
    "Downloaded by {email}" : "Descargado por {email}",
    "{file} downloaded via public link" : "{file} descargado vía enlace público",
    "{email} downloaded {file}" : "{email} descargó {file}",
    "Shared with group {group}" : "Compartido con el grupo {grupo}",
    "Removed share for group {group}" : "Eliminado el compartido para el grupo {group}",
    "{actor} shared with group {group}" : "{actor} compartió con el grupo {group}",
    "{actor} removed share for group {group}" : "{actor} eliminó el compartido para el grupo {group}",
    "You shared {file} with group {group}" : "Ha compartido {file} con el grupo {group}",
    "You removed group {group} from {file}" : "Ha eliminado el grupo  {group} del {file}",
    "{actor} shared {file} with group {group}" : "{actor} compartió {file} con el grupo {group}",
    "{actor} removed group {group} from {file}" : "{actor} eliminó grupo {group} de {file}",
    "Shared as public link" : "Compartido como enlace público",
    "Removed public link" : "Eliminado enlace público",
    "Public link expired" : "El enlace público ha expirado",
    "{actor} shared as public link" : "{actor} compartió como enlace público",
    "{actor} removed public link" : "{actor} eliminó el enlace público",
    "Public link of {actor} expired" : "Enlace público de {actor} caducado",
    "You shared {file} as public link" : "Compartió {file} como un enlace público",
    "You removed public link for {file}" : "Eliminó el enlace público para {file}",
    "Public link expired for {file}" : "Enlace público caducado para {file}",
    "{actor} shared {file} as public link" : "{actor} compartió {file} como enlace público",
    "{actor} removed public link for {file}" : "{actor} eliminó el enlace público para {file}",
    "Public link of {actor} for {file} expired" : "Enlace público de {actor} para {file} caducado",
    "{user} accepted the remote share" : "{user} aceptó el recurso compartido remotamente",
    "{user} declined the remote share" : "{user} rechazó el recurso compartido",
    "You received a new remote share {file} from {user}" : "Ha recibido un nuevo recurso compartido remoto {file} de {user}",
    "{user} accepted the remote share of {file}" : "{user} aceptó la compartición remota de {file}",
    "{user} declined the remote share of {file}" : "{user} rechazó el recurso compartido de {file}",
    "{user} unshared {file} from you" : "{user} dejó de compartir {file} contigo",
    "Shared with {user}" : "Compartido con {user}",
    "Removed share for {user}" : "Eliminó el recurso compartido a {user}",
    "{actor} shared with {user}" : "{actor} compartió con {user}",
    "{actor} removed share for {user}" : "{actor} eliminó recurso compartido para {user}",
    "Shared by {actor}" : "Compartido por {actor}",
    "{actor} removed share" : "{actor} eliminó el recurso compartido",
    "You shared {file} with {user}" : "Ha compartido {file} con {user}",
    "You removed {user} from {file}" : "Ha eliminado {user} de {file}",
    "{actor} shared {file} with {user}" : "{actor} compartió {file} con {user}",
    "{actor} removed {user} from {file}" : "{actor} eliminó a {user} de {file}",
    "{actor} shared {file} with you" : "{actor} compartió {file} contigo",
    "{actor} removed you from {file}" : "{actor} lo ha eliminado de {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Un archivo o carpeta compartida por correo o enlace público fue  <strong>descargado</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Se ha compartido un archivo o carpeta desde <strong>otro servidor</strong>",
    "A file or folder has been <strong>shared</strong>" : "Se ha <strong>compartido</strong> un archivo o carpeta",
    "Wrong share ID, share doesn't exist" : "El ID del recurso compartido no es correcto, el recurso compartido no existe",
    "could not delete share" : "No se ha podido eliminar el recurso compartido",
    "Could not delete share" : "No se ha podido eliminar el recurso compartido",
    "Please specify a file or folder path" : "Por favor, especifica la ubicación de un archivo o carpeta",
    "Wrong path, file/folder doesn't exist" : "Ubicación incorrecta, el archivo/carpeta no existe",
    "Could not create share" : "No se ha podido compartir",
    "invalid permissions" : "Permisos incorrectos",
    "Please specify a valid user" : "Por favor, especifica un usuario válido",
    "Group sharing is disabled by the administrator" : "Compartir en grupo está deshabilitado por el administrador",
    "Please specify a valid group" : "Por favor, especifica un grupo válido",
    "Public link sharing is disabled by the administrator" : "Compartir enlaces de forma pública está deshabilitado por el administrador",
    "Public upload disabled by the administrator" : "La subida pública está deshabilitado por el administrador",
    "Public upload is only possible for publicly shared folders" : "La subida publica solo es posible poara las carpetas publicas compartidas",
    "Invalid date, date format must be YYYY-MM-DD" : "Fecha inválida, el formato de las fechas debe ser YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Compartir %s ha fallado porque el repositorio no admite compartidos del tipo %s",
    "You cannot share to a Circle if the app is not enabled" : "No puede compartir a un Circulo si la aplicación no esta activada",
    "Please specify a valid circle" : "Por favor especifique un circulo valido",
    "Unknown share type" : "Tipo desconocido de recurso compartido",
    "Not a directory" : "No es un directorio",
    "Could not lock path" : "No se ha podido bloquear la ruta",
    "Wrong or no update parameter given" : "No se ha suministrado un parametro correcto",
    "Can't change permissions for public share links" : "No se pueden cambiar los permisos para los enlaces de recursos compartidos públicos",
    "Cannot increase permissions" : "No es posible aumentar permisos",
    "%s is publicly shared" : "%s ha sido compartido",
    "Share API is disabled" : "El API de compartir está deshabilitado",
    "File sharing" : "Compartir archivos",
    "This share is password-protected" : "Este elemento compartido está protegido por contraseña",
    "The password is wrong. Try again." : "La contraseña introducida es errónea. Inténtelo de nuevo.",
    "Password" : "Contraseña",
    "No entries found in this folder" : "No hay entradas en esta carpeta",
    "Name" : "Nombre",
    "Share time" : "Compartido hace",
    "Expiration date" : "Fecha de caducidad",
    "Sorry, this link doesn’t seem to work anymore." : "Vaya, este enlace parece que no volverá a funcionar.",
    "Reasons might be:" : "Las causas podrían ser:",
    "the item was removed" : "el elemento fue eliminado",
    "the link expired" : "el enlace expiró",
    "sharing is disabled" : "compartir está desactivado",
    "For more info, please ask the person who sent this link." : "Para mayor información, contacte a la persona que le envió el enlace.",
    "shared by %s" : "compartido por %s",
    "Add to your Nextcloud" : "Añadir a tu Nextcloud",
    "Download" : "Descargar",
    "Download %s" : "Descargar %s",
    "Direct link" : "Enlace directo",
    "Upload files to %s" : "Subir archivos a %s",
    "Select or drop files" : "Seleccione o arrastre y suelte archivos",
    "Uploading files…" : "Subiendo archivos...",
    "Uploaded files:" : "Archivos subidos:"
},
"nplurals=2; plural=(n != 1);");
